# FormDisplay

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**body_background_color** | **str** |  | [optional] 
**body_font_color** | **str** |  | [optional] 
**header_background_color** | **str** |  | [optional] 
**header_font_color** | **str** |  | [optional] 
**sender** | **str** |  | [optional] 
**submit_button_background_color** | **str** |  | [optional] 
**submit_button_font_color** | **str** |  | [optional] 
**submit_text** | **str** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


